import { selectRenderer } from './SelectRenderer.js';

export function renderMeasurementResults(measurementResults, language) {
  const container = document.getElementById('measurementResults');
  const title = document.createElement('h2');
  title.textContent = 'Measurement Results (' + language + ')';
  container.appendChild(title);

  // measurementResult can be an object or an array
  let results = measurementResults['dcc:measurementResult'];
  if (!Array.isArray(results)) {
    results = [results];
  }

  results.forEach(result => {
    // Render the measurement result title
    const resultTitle = document.createElement('h3');
    if (result['dcc:name'] && result['dcc:name']['dcc:content']) {
      let nameContent = result['dcc:name']['dcc:content'];
      if (Array.isArray(nameContent)) {
        // Find the content matching the selected language or fallback
        const match = nameContent.find(item => item.$ && item.$.lang === language) || nameContent[0];
        resultTitle.textContent = match._ || match;
      } else {
        resultTitle.textContent = nameContent._ || nameContent;
      }
    } else {
      resultTitle.textContent = 'Measurement Result';
    }
    container.appendChild(resultTitle);

    // Render results using dcc:results -> dcc:result
    if (result['dcc:results'] && result['dcc:results']['dcc:result']) {
      let resItems = result['dcc:results']['dcc:result'];
      if (!Array.isArray(resItems)) {
        resItems = [resItems];
      }
      resItems.forEach(res => {
        // Check if the result contains a dcc:data with a dcc:list that should be rendered as plot/table
        if (res['dcc:data'] && res['dcc:data']['dcc:list']) {
          const dataContainer = document.createElement('div');
          dataContainer.className = 'plot-table';
          // Use the global selectRenderer to decide how to render this data
          const renderedContent = selectRenderer(res['dcc:data']['dcc:list'], language);
          dataContainer.appendChild(renderedContent);
          container.appendChild(dataContainer);
        } else {
          // Fallback: simple placeholder
          const defaultContainer = document.createElement('div');
          defaultContainer.className = 'default-render';
          defaultContainer.textContent = 'Default rendering for measurement result.';
          container.appendChild(defaultContainer);
        }
      });
    }
  });
}
